@@ -102,7 +102,8 @@ class Hermes(object):
       example.baz.invalidate(2, 10)
           
       cache.clean(['math']) # invalidate entries tagged 'math'
-      cache.clean()         # flush cache''' 
+      cache.clean()         # flush cache
+  ''' 
   
   backend = None
   '''Cache backend'''
@@ -120,7 +121,8 @@ class Hermes(object):
     Positional agruments are backend class and mangler class. If ommited noop-backend
     and built-in mangler will be be used.
     
-    Keyword arguments comprise of ``ttl`` and backend parameters.'''
+    Keyword arguments comprise of ``ttl`` and backend parameters.
+    '''
     
     self.ttl = kwargs.pop('ttl', self.ttl)
     
@@ -138,7 +140,8 @@ class Hermes(object):
       :tags:  Cache entry tag list.
       
     ``@cache`` decoration is supported as well as 
-    ``@cache(ttl = 7200, tags = ('tag1', 'tag2'), key = lambda fn, *args, **kwargs: 'mykey')``.'''
+    ``@cache(ttl = 7200, tags = ('tag1', 'tag2'), key = lambda fn, *args, **kwargs: 'mykey')``.
+    '''
     
     if args and isinstance(args[0], (types.FunctionType, types.MethodType)):
       # @cache
@@ -167,16 +170,18 @@ class Cached(object):
   
   _callable = None
   '''The decorated callable, stays ``types.FunctionType`` if a function is decorated, 
-  otherwise it is transformed to ``types.MethodType`` by descriptor protocol implementation'''
+  otherwise it is transformed to ``types.MethodType`` on the instance clone by descriptor 
+  protocol implementation.
+  '''
   
   _ttl = None
-  '''Cache entry Time To Live for decarated callable'''
+  '''Cache entry Time To Live for decorated callable'''
   
   _keyFunc  = None
   '''Key creation function'''
   
   _tags = None
-  '''Cache entry tags for decarated callable'''
+  '''Cache entry tags for decorated callable'''
   
   
   def __init__(self, backend, mangler, ttl, callable, **kwargs):
@@ -240,9 +245,9 @@ class Cached(object):
     return value
   
   def __get__(self, instance, type):
-    '''Implements a non-data descriptor protocol.
+    '''Implements non-data descriptor protocol.
     
-    The invocation happens only when instance method is decorated, so  we can distinguish 
+    The invocation happens only when instance method is decorated, so we can distinguish 
     between decorated ``types.MethodType`` and ``types.FunctionType``. Python class 
     declaration mechanics prevent a decorator from having awareness of the class type, as 
     the function is received by the decorator before it becomes an instance method.
@@ -260,18 +265,27 @@ class Cached(object):
       m = Model()
       m.calc
       
-    Last attribute access results in the call, ``calc.__get__(calc, m, Model)``, where 
-    ``calc`` is instance of ``hermes.Cashed`` which decorates the original ``Model.calc``.
+    Last attribute access results in the call, ``calc.__get__(m, Model)``, where 
+    ``calc`` is instance of ``hermes.Cached`` which decorates the original ``Model.calc``.
     
-    For more details, http://docs.python.org/2/howto/descriptor.html#descriptor-protocol
+    Note, initially ``hermes.Cached`` is created on decoration per class method, when class 
+    type is created by the interperter, and is shared among all instances. Later, on attribute 
+    access, a copy is returned with bound ``_callable``, just like ordinary Python method 
+    descriptor works.    
+    
+    For more details, http://docs.python.org/2/howto/descriptor.html#descriptor-protocol.
     '''
     
     if not isinstance(self._callable, types.MethodType):
+      methodCached          = object.__new__(Cached)
+      methodCached.__dict__ = self.__dict__.copy()
       try:
-        self._callable = types.MethodType(self._callable, instance, type)
+        methodCached._callable = types.MethodType(self._callable, instance, type)
       except TypeError:
         # python3 compatibility
-        self._callable = types.MethodType(self._callable, instance)
+        methodCached._callable = types.MethodType(self._callable, instance)
+        
+      return methodCached
     
     return self
 
