@@ -3,9 +3,12 @@
 '''
 
 
+import sys
 import unittest
 import types
 import hashlib
+import random
+import datetime
 
 try:
   import cPickle as pickle
@@ -85,6 +88,27 @@ def createFixture(cache):
   return Fixture()
 
 
+def benchmark(fixture):
+  try:
+    # Python 2
+    xrange = xrange  # @UndefinedVariable
+  except NameError:
+    # Python 3
+    xrange = range
+  
+  args   = [(random.randint(0, 4096), random.randint(0, 4096)) for _ in xrange(1024)]
+  repeat = 8192
+  for method in ('simple', 'tagged'):
+    print('\n{0} {1} {0}'.format('-' * 20, method))
+    start = datetime.datetime.now()
+    for _ in xrange(repeat):
+      getattr(fixture, method)(*random.choice(args))
+    delta = datetime.datetime.now() - start
+    print('  repeated:    {0:,}'.format(repeat))
+    print('  time:        {0}'.format(delta))
+    print('  call/second: {0:,.0f}'.format(repeat / delta.total_seconds()))
+  
+
 class TestReadme(unittest.TestCase):
   
   def testUsage(self):
@@ -213,4 +237,29 @@ class TestWrapping(unittest.TestCase):
     self.assertTrue(isinstance(fixture.simple, hermes.Cached))
     self.assertEqual('simple', fixture.simple.__name__)
     self.assertEqual('Here be dragons... seriously just a docstring test', fixture.simple.__doc__)
+    
+  def testInstanceIsolation(self):
+    
+    class Fixture(object):
+      
+      def __init__(self, marker):
+        self.marker = marker
+      
+      @self.testee  
+      def foo(self):
+        return self.marker
+      
+      def bar(self):
+        pass
+      
+    f1 = Fixture(12)
+    f2 = Fixture(24)
+    
+    # verify instances are not shared
+    self.assertIsNot(f1.foo, f2.foo)
+    # like it is normally the case of normal methods
+    self.assertIsNot(f1.bar, f2.bar)
+    
+    self.assertEqual(12, f1.foo())
+    self.assertEqual(24, f2.foo())
 
